@@ -5,11 +5,11 @@
 #include "ctrl_classifier_controller.h"
 #include "storage/data_database.h"
 #include "storage/data_database_reader.h"
-#include "data_diagram.h"
-#include "data_diagram_type.h"
+#include "entity/data_diagram.h"
+#include "entity/data_diagram_type.h"
 #include "set/data_visible_classifier.h"
-#include "data_feature.h"
-#include "data_relationship.h"
+#include "entity/data_feature.h"
+#include "entity/data_relationship.h"
 #include "test_fixture.h"
 #include "test_expect.h"
 #include "test_environment_assert.h"
@@ -68,14 +68,13 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
     assert( fix != NULL );
     u8_error_t ctrl_err;
     u8_error_t data_err;
-    data_row_id_t diagram_id;
-    data_row_id_t classifier_id;
-    data_row_id_t diagele_id;
+    data_row_t diagram_id;
+    data_row_t classifier_id;
+    data_row_t diagele_id;
     data_classifier_t read_classifier;
     ctrl_classifier_controller_t *classifier_ctrl;
     ctrl_diagram_controller_t *diagram_ctrl;
-    uint32_t read_vis_classifiers_count;
-    data_visible_classifier_t read_vis_classifiers[2];
+    data_visible_classifier_t read_vis_classifier;
     data_classifier_t *first_classifier;
     classifier_ctrl = ctrl_controller_get_classifier_control_ptr( &((*fix).controller) );
     diagram_ctrl = ctrl_controller_get_diagram_control_ptr ( &((*fix).controller) );
@@ -100,19 +99,19 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
                                                                 );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_classifier_destroy ( &new_classifier );
-        TEST_EXPECT( DATA_ROW_ID_VOID != classifier_id );
+        TEST_EXPECT( DATA_ROW_VOID != classifier_id );
     }
 
     /* create the root diagram */
     {
-        diagram_id = DATA_ROW_ID_VOID;
+        diagram_id = DATA_ROW_VOID;
         ctrl_err = ctrl_diagram_controller_create_root_diagram_if_not_exists ( diagram_ctrl,
                                                                                DATA_DIAGRAM_TYPE_UML_ACTIVITY_DIAGRAM,
                                                                                "root_diagram",
                                                                                &diagram_id
                                                                              );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_EXPECT( DATA_ROW_ID_VOID != diagram_id );
+        TEST_EXPECT( DATA_ROW_VOID != diagram_id );
     }
 
     /* create a diagramelement */
@@ -122,7 +121,7 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
                                        diagram_id,
                                        classifier_id,
                                        DATA_DIAGRAMELEMENT_FLAG_NONE,
-                                       DATA_ROW_ID_VOID
+                                       DATA_ROW_VOID
                                      );
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele,
@@ -131,7 +130,7 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
                                                                  );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele );
-        TEST_EXPECT( DATA_ROW_ID_VOID != diagele_id );
+        TEST_EXPECT( DATA_ROW_VOID != diagele_id );
     }
 
     /* read this record */
@@ -170,11 +169,10 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
-    /* search several records, result array too small */
+    /* search a record */
     {
-        data_visible_classifier_init_empty( &(read_vis_classifiers[0]) );
-        data_visible_classifier_init_empty( &(read_vis_classifiers[1]) );
-        first_classifier = data_visible_classifier_get_classifier_ptr( &(read_vis_classifiers[0]) );
+        data_visible_classifier_init_empty( &(read_vis_classifier) );
+        first_classifier = data_visible_classifier_get_classifier_ptr( &(read_vis_classifier) );
         data_uuid_t uuid;
         data_uuid_init_new( &uuid );
 
@@ -190,29 +188,19 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
                                 data_uuid_get_string( &uuid )
                               );
 
-        data_err = data_database_reader_get_classifiers_by_diagram_id ( &((*fix).db_reader), diagram_id, 0, &read_vis_classifiers, &read_vis_classifiers_count );
-        TEST_EXPECT_EQUAL_INT( U8_ERROR_ARRAY_BUFFER_EXCEEDED, data_err );
-        TEST_EXPECT_EQUAL_INT( 0, read_vis_classifiers_count );
-        /* check that old data is not overwritten: */
-        TEST_EXPECT_EQUAL_INT( 0x1234, data_classifier_get_row_id( first_classifier ) );
-        TEST_EXPECT_EQUAL_INT( DATA_CLASSIFIER_TYPE_COMPONENT, data_classifier_get_main_type( first_classifier ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "stereo", data_classifier_get_stereotype_const( first_classifier ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "my_name", data_classifier_get_name_const( first_classifier ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "descr", data_classifier_get_description_const( first_classifier ) ) );
-        TEST_EXPECT_EQUAL_INT( 1000, data_classifier_get_x_order( first_classifier ) );
-        TEST_EXPECT_EQUAL_INT( 400, data_classifier_get_y_order( first_classifier ) );
-        TEST_EXPECT_EQUAL_INT( 398, data_classifier_get_list_order( first_classifier ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( data_uuid_get_string( &uuid ), data_classifier_get_uuid_const( first_classifier ) ) );
-
-        data_uuid_destroy( &uuid );
-    }
-
-    /* search several records, result array sufficient */
-    {
-        data_err = data_database_reader_get_classifiers_by_diagram_id ( &((*fix).db_reader), diagram_id, 2, &read_vis_classifiers, &read_vis_classifiers_count );
+        data_visible_classifier_iterator_t visible_classifier_iterator;
+        data_err = data_visible_classifier_iterator_init_empty( &visible_classifier_iterator );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( 1, read_vis_classifiers_count );
+        data_err = data_database_reader_get_visible_classifiers_by_diagram_id( &((*fix).db_reader),
+                                                                               diagram_id,
+                                                                               &visible_classifier_iterator
+                                                                             );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err )
+        ;
+        TEST_EXPECT_EQUAL_INT( true, data_visible_classifier_iterator_has_next( &visible_classifier_iterator ) );
         /* check that new data is available */
+        data_err = data_visible_classifier_iterator_next( &visible_classifier_iterator, &read_vis_classifier );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
         TEST_EXPECT_EQUAL_INT( classifier_id, data_classifier_get_row_id( first_classifier ) );
         TEST_EXPECT_EQUAL_INT( DATA_CLASSIFIER_TYPE_NODE, data_classifier_get_main_type( first_classifier ) );
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "my_new_stereotype", data_classifier_get_stereotype_const( first_classifier ) ) );
@@ -220,6 +208,10 @@ static test_case_result_t classifier_create_read_modify_read( test_fixture_t *fi
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "my_new_classifier_description", data_classifier_get_description_const( first_classifier ) ) );
         TEST_EXPECT_EQUAL_INT( 6789, data_classifier_get_x_order( first_classifier ) );
         TEST_EXPECT_EQUAL_INT( 789, data_classifier_get_y_order( first_classifier ) );
+
+        TEST_EXPECT_EQUAL_INT( false, data_visible_classifier_iterator_has_next( &visible_classifier_iterator ) );
+        data_err = data_visible_classifier_iterator_destroy( &visible_classifier_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
     }
     return TEST_CASE_RESULT_OK;
 }
@@ -236,7 +228,7 @@ static test_case_result_t features_CRURDR( test_fixture_t *fix )
     data_uuid_init_new( &uuid );
 
     /* create a feature */
-    data_row_id_t new_feature_id;
+    data_row_t new_feature_id;
     {
         data_feature_t probe;
         data_err = data_feature_init ( &probe,
@@ -354,20 +346,20 @@ static test_case_result_t relationship_CRURDR( test_fixture_t *fix )
     data_uuid_init_new( &uuid );
 
     /* create a relationship */
-    data_row_id_t new_relationship_id;
+    data_row_t new_relationship_id;
     {
         data_relationship_t probe;
         data_err = data_relationship_init ( &probe,
                                             34, /* relationship_id */
-                                            DATA_RELATIONSHIP_TYPE_UML_COMPOSITION, /* relationship_main_type */
                                             86000, /* from_classifier_id */
+                                            DATA_ROW_VOID, /* from_feature_id */
                                             86001, /* to_classifier_id */
+                                            100666, /* to_feature_id */
+                                            DATA_RELATIONSHIP_TYPE_UML_COMPOSITION, /* relationship_main_type */
                                             "stereo_t", /* stereotype */
                                             "the composition is more", /* name */
                                             "than the sum of its parts", /* description */
                                             -66000, /* list_order */
-                                            DATA_ROW_ID_VOID, /* from_feature_id */
-                                            100666, /* to_feature_id */
                                             data_uuid_get_string( &uuid )
                                           );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
@@ -393,7 +385,7 @@ static test_case_result_t relationship_CRURDR( test_fixture_t *fix )
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "the composition is more", data_relationship_get_name_const( &check ) ) );
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "than the sum of its parts", data_relationship_get_description_const( &check ) ) );
         TEST_EXPECT_EQUAL_INT( -66000, data_relationship_get_list_order( &check ) );
-        TEST_EXPECT_EQUAL_INT( DATA_ROW_ID_VOID, data_relationship_get_from_feature_row_id( &check ) );
+        TEST_EXPECT_EQUAL_INT( DATA_ROW_VOID, data_relationship_get_from_feature_row_id( &check ) );
         TEST_EXPECT_EQUAL_INT( 100666, data_relationship_get_to_feature_row_id( &check ) );
         TEST_EXPECT_EQUAL_INT( 0, strcmp( data_uuid_get_string( &uuid ), data_relationship_get_uuid_const( &check ) ) );
     }
@@ -444,7 +436,7 @@ static test_case_result_t relationship_CRURDR( test_fixture_t *fix )
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "async message", data_relationship_get_name_const( &check2 ) ) );
         TEST_EXPECT_EQUAL_INT( 0, strcmp( "good for modularization", data_relationship_get_description_const( &check2 ) ) );
         TEST_EXPECT_EQUAL_INT( -88000, data_relationship_get_list_order( &check2 ) );
-        TEST_EXPECT_EQUAL_INT( DATA_ROW_ID_VOID, data_relationship_get_from_feature_row_id( &check2 ) );
+        TEST_EXPECT_EQUAL_INT( DATA_ROW_VOID, data_relationship_get_from_feature_row_id( &check2 ) );
         TEST_EXPECT_EQUAL_INT( 100666, data_relationship_get_to_feature_row_id( &check2 ) );
         TEST_EXPECT_EQUAL_INT( 0, strcmp( data_uuid_get_string( &uuid ), data_relationship_get_uuid_const( &check2 ) ) );
     }
@@ -471,7 +463,7 @@ static test_case_result_t relationship_CRURDR( test_fixture_t *fix )
 
 
 /*
- * Copyright 2016-2024 Andreas Warnke
+ * Copyright 2016-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
