@@ -60,6 +60,13 @@ struct gui_resources_struct {
 
     GdkPixbuf *background_column;
 
+    GdkTexture *sketch_create;
+    GdkTexture *sketch_refine;
+    GdkTexture *sketch_relate;
+    GdkTexture *sketch_move_h;
+    GdkTexture *sketch_move_v;
+    GdkTexture *sketch_move_2d;
+
     GdkTexture *type_undef;
 
     GdkTexture *type_diag_activity;
@@ -93,12 +100,12 @@ struct gui_resources_struct {
     GdkTexture *type_clas_constraint;
     GdkTexture *type_clas_decision;
     GdkTexture *type_clas_deephistory;
-    GdkTexture *type_clas_diagram;
     GdkTexture *type_clas_final;
     GdkTexture *type_clas_fork;
     GdkTexture *type_clas_history;
     GdkTexture *type_clas_image;
     GdkTexture *type_clas_initial;
+    GdkTexture *type_clas_interaction_use;
     GdkTexture *type_clas_interface;
     GdkTexture *type_clas_join;
     GdkTexture *type_clas_node;
@@ -415,6 +422,48 @@ static inline GdkTexture *gui_resources_get_search_search ( const gui_resources_
  */
 static inline GdkPixbuf *gui_resources_get_background_column ( const gui_resources_t *this_ );
 
+/*!
+ *  \brief gets the sketch_create as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_create ( const gui_resources_t *this_ );
+
+/*!
+ *  \brief gets the sketch_refine as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_refine ( const gui_resources_t *this_ );
+
+/*!
+ *  \brief gets the sketch_relate as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_relate ( const gui_resources_t *this_ );
+
+/*!
+ *  \brief gets the sketch_move_h as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_move_h ( const gui_resources_t *this_ );
+
+/*!
+ *  \brief gets the sketch_move_v as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_move_v ( const gui_resources_t *this_ );
+
+/*!
+ *  \brief gets the sketch_move_2d as GdkTexture
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_sketch_move_2d ( const gui_resources_t *this_ );
+
 /*!
  *  \brief gets the type_undef
  *
@@ -632,13 +681,6 @@ static inline GdkTexture *gui_resources_get_type_clas_decision ( const gui_resou
  */
 static inline GdkTexture *gui_resources_get_type_clas_deephistory ( const gui_resources_t *this_ );
 
-/*!
- *  \brief gets the type_clas_diagram
- *
- *  \param this_ pointer to own object attributes
- */
-static inline GdkTexture *gui_resources_get_type_clas_diagram ( const gui_resources_t *this_ );
-
 /*!
  *  \brief gets the type_clas_final
  *
@@ -674,6 +716,13 @@ static inline GdkTexture *gui_resources_get_type_clas_image ( const gui_resource
  */
 static inline GdkTexture *gui_resources_get_type_clas_initial ( const gui_resources_t *this_ );
 
+/*!
+ *  \brief gets the type_clas_interaction_use
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline GdkTexture *gui_resources_get_type_clas_interaction_use ( const gui_resources_t *this_ );
+
 /*!
  *  \brief gets the type_clas_interface
  *
