@@ -5,11 +5,17 @@
 #include "gui_gtk.h"
 #include <assert.h>
 
-void gui_sketch_card_painter_init( gui_sketch_card_painter_t *this_ )
+void gui_sketch_card_painter_init( gui_sketch_card_painter_t *this_,
+                                   gui_resources_t *resources,
+                                   gui_sketch_texture_t *texture_downloader )
 {
     U8_TRACE_BEGIN();
+    assert( resources != NULL );
+    assert( texture_downloader != NULL );
 
     gui_sketch_style_init( &((*this_).sketch_style) );
+    (*this_).resources = resources;
+    (*this_).texture_downloader = texture_downloader;
 
     U8_TRACE_END();
 }
@@ -18,6 +24,8 @@ void gui_sketch_card_painter_destroy( gui_sketch_card_painter_t *this_ )
 {
     U8_TRACE_BEGIN();
 
+    (*this_).resources = NULL;
+    (*this_).texture_downloader = NULL;
     gui_sketch_style_destroy( &((*this_).sketch_style) );
 
     U8_TRACE_END();
@@ -38,6 +46,7 @@ void gui_sketch_card_painter_draw_overlay( gui_sketch_card_painter_t *this_,
     {
         case GUI_TOOL_NAVIGATE:
         {
+            gui_sketch_card_painter_private_draw_nav_mode( this_, drag_state, card_under_mouse, cr );
         }
         break;
 
@@ -76,6 +85,31 @@ void gui_sketch_card_painter_draw_overlay( gui_sketch_card_painter_t *this_,
     U8_TRACE_END();
 }
 
+void gui_sketch_card_painter_private_draw_nav_mode( gui_sketch_card_painter_t *this_,
+                                                    const gui_sketch_drag_state_t *drag_state,
+                                                    const gui_sketch_card_t *card_under_mouse,
+                                                    cairo_t *cr )
+{
+    U8_TRACE_BEGIN();
+    assert( NULL != drag_state );
+    assert( NULL != cr );
+
+    if ( gui_sketch_drag_state_is_waiting_for_move ( drag_state ) )
+    {
+        const data_full_id_t *const dragged_object = gui_sketch_drag_state_get_dragged_object_const( drag_state );
+        const data_id_t *const dragged_primary = data_full_id_get_primary_id_const( dragged_object );
+        const bool dragging_diagram = ( DATA_TABLE_DIAGRAM == data_id_get_table( dragged_primary ) );
+        if ( dragging_diagram )
+        {
+            const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
+            const int32_t to_y = gui_sketch_drag_state_get_to_y ( drag_state );
+            GdkTexture *icon = gui_resources_get_sketch_move_v( (*this_).resources );
+            gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+        }
+    }
+
+    U8_TRACE_END();
+}
 
 void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *this_,
                                                      const gui_sketch_drag_state_t *drag_state,
@@ -88,8 +122,7 @@ void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *
 
     if ( gui_sketch_drag_state_is_dragging ( drag_state ) )
     {
-        const data_full_id_t *const dragged_object
-            = gui_sketch_drag_state_get_dragged_object_const( drag_state );
+        const data_full_id_t *const dragged_object = gui_sketch_drag_state_get_dragged_object_const( drag_state );
         const data_id_t *const dragged_primary = data_full_id_get_primary_id_const( dragged_object );
         const bool dragging_classifier = ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( dragged_primary ) );
 
@@ -104,8 +137,10 @@ void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *
 
             if ( draw_2d_diagram && dragging_classifier )
             {
+#if 0
                 /* draw grid line crossings */
                 gui_sketch_card_painter_private_draw_grid( this_, card_under_mouse, cr );
+#endif
 
                 /* draw new grid lines that visualize the order of classifiers */
                 const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
@@ -115,6 +150,40 @@ void gui_sketch_card_painter_private_draw_edit_mode( gui_sketch_card_painter_t *
         }
     }
 
+    if ( gui_sketch_drag_state_is_waiting_for_move ( drag_state ) )
+    {
+        const data_full_id_t *const dragged_object = gui_sketch_drag_state_get_dragged_object_const( drag_state );
+        const data_id_t *const dragged_primary = data_full_id_get_primary_id_const( dragged_object );
+        const bool dragging_classifier = ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( dragged_primary ) );
+        const bool dragging_feature = ( DATA_TABLE_FEATURE == data_id_get_table( dragged_primary ) );
+        const bool dragging_relationship = ( DATA_TABLE_RELATIONSHIP == data_id_get_table( dragged_primary ) );
+        const int32_t to_x = gui_sketch_drag_state_get_to_x ( drag_state );
+        const int32_t to_y = gui_sketch_drag_state_get_to_y ( drag_state );
+        if ( dragging_classifier || dragging_feature )
+        {
+            GdkTexture *icon = gui_resources_get_sketch_move_2d( (*this_).resources );
+            gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+        }
+        else if ( dragging_relationship )
+        {
+            const data_diagram_t *diag = gui_sketch_card_get_diagram_const ( card_under_mouse );
+            if ( NULL != card_under_mouse )
+            {
+                const data_diagram_type_t diag_type = data_diagram_get_diagram_type( diag );
+                if ( diag_type == DATA_DIAGRAM_TYPE_UML_SEQUENCE_DIAGRAM )
+                {
+                    GdkTexture *icon = gui_resources_get_sketch_move_v( (*this_).resources );
+                    gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+                }
+                else if ( diag_type == DATA_DIAGRAM_TYPE_UML_TIMING_DIAGRAM )
+                {
+                    GdkTexture *icon = gui_resources_get_sketch_move_h( (*this_).resources );
+                    gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+                }
+            }
+        }
+    }
+
     U8_TRACE_END();
 }
 
@@ -168,25 +237,36 @@ void gui_sketch_card_painter_private_draw_create_mode( gui_sketch_card_painter_t
             /* draw grid */
             if (( draw_new_classifier )&&( draw_2d_diagram ))
             {
+#if 0
                 /* draw grid line crossings */
                 gui_sketch_card_painter_private_draw_grid( this_, card_under_mouse, cr );
-
+#endif
                 /* draw new grid lines that visualize the order of classifiers */
                 gui_sketch_card_painter_private_visualize_order( this_, card_under_mouse, to_x, to_y, cr );
             }
 
             /* draw boxes and arrow icons */
-            if ( draw_new_classifier )
-            {
-                gui_sketch_card_painter_private_draw_new_classifier( this_, to_x, to_y, cr );
-            }
             if ( draw_new_feature )
             {
-                gui_sketch_card_painter_private_draw_new_feature( this_, to_x, to_y, cr );
+                assert( draw_new_relationship );
+                assert( ! draw_new_classifier );
+                GdkTexture *icon = gui_resources_get_sketch_refine( (*this_).resources );
+                gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
             }
-            if ( draw_new_relationship )
+            else if ( draw_new_relationship )
             {
-                gui_sketch_card_painter_private_draw_new_relationship( this_, to_x, to_y, cr );
+                assert( ! draw_new_classifier );
+                GdkTexture *icon = gui_resources_get_sketch_relate( (*this_).resources );
+                gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+            }
+            else if ( draw_new_classifier )
+            {
+                GdkTexture *icon = gui_resources_get_sketch_create( (*this_).resources );
+                gui_sketch_texture_draw( (*this_).texture_downloader, icon, to_x-16, to_y-16-2, cr );  /* 2 is extra gap*/
+            }
+            else
+            {
+                /* draw nothing */
             }
         }
     }
@@ -279,100 +359,7 @@ void gui_sketch_card_painter_private_draw_arrow( gui_sketch_card_painter_t *this
     U8_TRACE_END();
 }
 
-void gui_sketch_card_painter_private_draw_new_classifier( gui_sketch_card_painter_t *this_,
-                                                          int32_t x,
-                                                         int32_t y,
-                                                         cairo_t *cr )
-{
-    U8_TRACE_BEGIN();
-    assert( NULL != cr );
-
-    const GdkRGBA high_color = gui_sketch_style_get_highlight_color( &((*this_).sketch_style) );
-    cairo_set_source_rgba( cr, high_color.red, high_color.green, high_color.blue, high_color.alpha );
-    static const int32_t ICON_UNIT = 2;
-    static const int32_t DIST = 12;
-
-    /* star */
-    const int32_t star_center_x = x+(1)*ICON_UNIT;
-    const int32_t star_center_y = y-DIST-6*ICON_UNIT;
-    cairo_move_to ( cr, star_center_x, star_center_y-2*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x, star_center_y+2*ICON_UNIT );
-    cairo_move_to ( cr, star_center_x-2*ICON_UNIT, star_center_y-1*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x+2*ICON_UNIT, star_center_y+1*ICON_UNIT );
-    cairo_move_to ( cr, star_center_x-2*ICON_UNIT, star_center_y+1*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x+2*ICON_UNIT, star_center_y-1*ICON_UNIT );
-
-    /* big box */
-    cairo_move_to ( cr, x-1*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x-8*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x-8*ICON_UNIT, y-DIST+3*ICON_UNIT );
-    cairo_line_to ( cr, x+1*ICON_UNIT, y-DIST+3*ICON_UNIT );
-    cairo_line_to ( cr, x+1*ICON_UNIT, y-DIST-2*ICON_UNIT );
-
-    cairo_stroke (cr);
-
-    U8_TRACE_END();
-}
-
-void gui_sketch_card_painter_private_draw_new_feature( gui_sketch_card_painter_t *this_,
-                                                       int32_t x,
-                                                       int32_t y,
-                                                       cairo_t *cr )
-{
-    U8_TRACE_BEGIN();
-    assert( NULL != cr );
-
-    const GdkRGBA high_color = gui_sketch_style_get_highlight_color( &((*this_).sketch_style) );
-    cairo_set_source_rgba( cr, high_color.red, high_color.green, high_color.blue, high_color.alpha );
-    static const int32_t ICON_UNIT = 2;
-    static const int32_t DIST = 12;
-
-    /* star */
-    const int32_t star_center_x = x+(-2)*ICON_UNIT;
-    const int32_t star_center_y = y-DIST-6*ICON_UNIT;
-    cairo_move_to ( cr, star_center_x, star_center_y-2*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x, star_center_y+2*ICON_UNIT );
-    cairo_move_to ( cr, star_center_x-2*ICON_UNIT, star_center_y-1*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x+2*ICON_UNIT, star_center_y+1*ICON_UNIT );
-    cairo_move_to ( cr, star_center_x-2*ICON_UNIT, star_center_y+1*ICON_UNIT );
-    cairo_line_to ( cr, star_center_x+2*ICON_UNIT, star_center_y-1*ICON_UNIT );
-
-    /* small box */
-    cairo_move_to ( cr, x-4*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x-8*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x-8*ICON_UNIT, y-DIST-2*ICON_UNIT );
-    cairo_line_to ( cr, x-2*ICON_UNIT, y-DIST-2*ICON_UNIT );
-
-    cairo_stroke (cr);
-
-    U8_TRACE_END();
-}
-
-void gui_sketch_card_painter_private_draw_new_relationship( gui_sketch_card_painter_t *this_,
-                                                            int32_t x,
-                                                            int32_t y,
-                                                            cairo_t *cr )
-{
-    U8_TRACE_BEGIN();
-    assert( NULL != cr );
-
-    const GdkRGBA high_color = gui_sketch_style_get_highlight_color( &((*this_).sketch_style) );
-    cairo_set_source_rgba( cr, high_color.red, high_color.green, high_color.blue, high_color.alpha );
-    static const int32_t ICON_UNIT = 2;
-    static const int32_t DIST = 12;
-
-    /* arrow */
-    cairo_move_to ( cr, x+2*ICON_UNIT, y-DIST-0*ICON_UNIT );
-    cairo_line_to ( cr, x+8*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x+5*ICON_UNIT, y-DIST-5*ICON_UNIT );
-    cairo_move_to ( cr, x+8*ICON_UNIT, y-DIST-6*ICON_UNIT );
-    cairo_line_to ( cr, x+7*ICON_UNIT, y-DIST-3*ICON_UNIT );
-
-    cairo_stroke (cr);
-
-    U8_TRACE_END();
-}
-
+#if 0
 void gui_sketch_card_painter_private_draw_grid( gui_sketch_card_painter_t *this_,
                                                 const gui_sketch_card_t *card_under_mouse,
                                                 cairo_t *cr )
@@ -411,6 +398,7 @@ void gui_sketch_card_painter_private_draw_grid( gui_sketch_card_painter_t *this_
 
     U8_TRACE_END();
 }
+#endif
 
 void gui_sketch_card_painter_private_visualize_order( gui_sketch_card_painter_t *this_,
                                                       const gui_sketch_card_t *card_under_mouse,
@@ -446,6 +434,10 @@ void gui_sketch_card_painter_private_visualize_order( gui_sketch_card_painter_t
     const layout_visible_set_t *const layout_data = gui_sketch_card_get_visible_set( card_under_mouse );
     const uint32_t classifiers = layout_visible_set_get_visible_classifier_count( layout_data );
 
+    /* prepare draw */
+    const GdkRGBA high_color = gui_sketch_style_get_highlight_color( &((*this_).sketch_style) );
+    cairo_set_source_rgba( cr, high_color.red, high_color.green, high_color.blue, high_color.alpha );
+
     /* to draw x, follow y from top to bottom */
     if (( grid_kind == GEOMETRY_GRID_KIND_X )||( grid_kind == GEOMETRY_GRID_KIND_XY ))
     {
@@ -579,6 +571,7 @@ void gui_sketch_card_painter_private_visualize_order( gui_sketch_card_painter_t
         }
         /* draw to end point and stroke the drawn path */
         cairo_line_to( cr, current_pos_x, bottom );
+        if ( ! geometry_non_linear_scale_is_order_on_grid( x_scale, order_at_x ) )
         {
             double dashes[2];
             dashes[0] = 2.0 * gap;  /* on segment */
@@ -722,6 +715,7 @@ void gui_sketch_card_painter_private_visualize_order( gui_sketch_card_painter_t
         }
         /* draw to end point and stroke the drawn path */
         cairo_line_to( cr, right, current_pos_y );
+        if ( ! geometry_non_linear_scale_is_order_on_grid( y_scale, order_at_y ) )
         {
             double dashes[2];
             dashes[0] = 2.0 * gap;  /* on segment */
