@@ -16,10 +16,9 @@
 #include "io_element_writer.h"
 #include "xmi/xmi_interaction_writer.h"
 #include "set/data_visible_set.h"
-#include "set/data_node_set.h"
 #include "set/data_stat.h"
 #include "storage/data_database_reader.h"
-#include "data_table.h"
+#include "entity/data_table.h"
 #include "data_rules.h"
 #include "u8list/universal_array_list.h"
 #include "u8/u8_error.h"
@@ -175,7 +174,7 @@ u8_error_t io_export_interaction_traversal_private_iterate_node_features( io_exp
 
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
