@@ -15,18 +15,14 @@
 #define META_INFO_PROGRAM_ID_STR "crystal-facet-uml"
 /* X-Desktop ID */
 #define META_INFO_APPLICATION_ID_STR "crystal-facet-uml.desktop"
-#define META_INFO_COPYRIGHT_STR /*Copyright*/ "2016-2024 Andreas Warnke"
-#ifdef __linux__
+#define META_INFO_COPYRIGHT_STR /*Copyright*/ "2016-2025 Andreas Warnke"
 #define META_INFO_LICENSE_STR "Apache-2.0"  /* sqlite3 linked dynamicyally */
-#else  /* __linux__ */
-#define META_INFO_LICENSE_STR "Apache-2.0 (includes sqlite3 which is public domain)"  /* sqlite3 linked statically */
-#endif  /* __linux__ */
 
 #endif  /* META_INFO_H */
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
